"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecurityGroup._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: SecurityGroup._Status.ValueType  # 0
        CREATING: SecurityGroup._Status.ValueType  # 1
        """Security group is being created."""
        ACTIVE: SecurityGroup._Status.ValueType  # 2
        """Security is active and it's rules are applied to the network interfaces."""
        UPDATING: SecurityGroup._Status.ValueType  # 3
        """Security group is updating. Updating is a long operation because we must update all instances in SG."""
        DELETING: SecurityGroup._Status.ValueType  # 4
        """Instance is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: SecurityGroup.Status.ValueType  # 0
    CREATING: SecurityGroup.Status.ValueType  # 1
    """Security group is being created."""
    ACTIVE: SecurityGroup.Status.ValueType  # 2
    """Security is active and it's rules are applied to the network interfaces."""
    UPDATING: SecurityGroup.Status.ValueType  # 3
    """Security group is updating. Updating is a long operation because we must update all instances in SG."""
    DELETING: SecurityGroup.Status.ValueType  # 4
    """Instance is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NETWORK_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    DEFAULT_FOR_NETWORK_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the security group."""
    folder_id: builtins.str
    """ID of the folder that the security group belongs to."""
    name: builtins.str
    """Name of the security group. 
    The name must be unique within the folder. 
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Description of the security group. 0-256 characters long."""
    network_id: builtins.str
    """ID of the network that the security group belongs to."""
    status: global___SecurityGroup.Status.ValueType
    """Security group status."""
    default_for_network: builtins.bool
    """Flag that indicates that the security group is the default for the network."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs. 
        No more than 64 per resource.
        The maximum string length in characters for each value is 63. 
        Each value must match the regular expression `[-_./\\\\@0-9a-z]*`. 
        The string length in characters for each key must be 1-63. 
        Each key must match the regular expression `[a-z][-_./\\\\@0-9a-z]*`.
        """

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupRule]:
        """List of the security group rules."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        network_id: builtins.str = ...,
        status: global___SecurityGroup.Status.ValueType = ...,
        rules: collections.abc.Iterable[global___SecurityGroupRule] | None = ...,
        default_for_network: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "default_for_network", b"default_for_network", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "network_id", b"network_id", "rules", b"rules", "status", b"status"]) -> None: ...

global___SecurityGroup = SecurityGroup

@typing.final
class SecurityGroupRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Direction:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _DirectionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SecurityGroupRule._Direction.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DIRECTION_UNSPECIFIED: SecurityGroupRule._Direction.ValueType  # 0
        INGRESS: SecurityGroupRule._Direction.ValueType  # 1
        """Allows ingress traffic."""
        EGRESS: SecurityGroupRule._Direction.ValueType  # 2
        """Allows egress traffic."""

    class Direction(_Direction, metaclass=_DirectionEnumTypeWrapper): ...
    DIRECTION_UNSPECIFIED: SecurityGroupRule.Direction.ValueType  # 0
    INGRESS: SecurityGroupRule.Direction.ValueType  # 1
    """Allows ingress traffic."""
    EGRESS: SecurityGroupRule.Direction.ValueType  # 2
    """Allows egress traffic."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    DIRECTION_FIELD_NUMBER: builtins.int
    PORTS_FIELD_NUMBER: builtins.int
    PROTOCOL_NAME_FIELD_NUMBER: builtins.int
    PROTOCOL_NUMBER_FIELD_NUMBER: builtins.int
    CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_ID_FIELD_NUMBER: builtins.int
    PREDEFINED_TARGET_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the rule.
    generated by api server after rule creation
    """
    description: builtins.str
    """Description of the rule. 0-256 characters long."""
    direction: global___SecurityGroupRule.Direction.ValueType
    """The direction of network traffic allowed by this rule."""
    protocol_name: builtins.str
    """Protocol name. Null value means any protocol.
    Values from [IANA](https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml).
    """
    protocol_number: builtins.int
    """Protocol number from [IANA protocol numbers](https://www.iana.org/assignments/protocol-numbers/protocol-numbers.xhtml)."""
    security_group_id: builtins.str
    """ID of the security group to add rule to."""
    predefined_target: builtins.str
    """Predefined target. See [security groups rules](/docs/vpc/concepts/security-groups#security-groups-rules) for more information."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def ports(self) -> global___PortRange:
        """The range of ports that allow traffic to pass through. Null value means any."""

    @property
    def cidr_blocks(self) -> global___CidrBlocks:
        """CIDR blocks to allow to recieve or send traffic."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        direction: global___SecurityGroupRule.Direction.ValueType = ...,
        ports: global___PortRange | None = ...,
        protocol_name: builtins.str = ...,
        protocol_number: builtins.int = ...,
        cidr_blocks: global___CidrBlocks | None = ...,
        security_group_id: builtins.str = ...,
        predefined_target: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cidr_blocks", b"cidr_blocks", "ports", b"ports", "predefined_target", b"predefined_target", "security_group_id", b"security_group_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cidr_blocks", b"cidr_blocks", "description", b"description", "direction", b"direction", "id", b"id", "labels", b"labels", "ports", b"ports", "predefined_target", b"predefined_target", "protocol_name", b"protocol_name", "protocol_number", b"protocol_number", "security_group_id", b"security_group_id", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["cidr_blocks", "security_group_id", "predefined_target"] | None: ...

global___SecurityGroupRule = SecurityGroupRule

@typing.final
class PortRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FROM_PORT_FIELD_NUMBER: builtins.int
    TO_PORT_FIELD_NUMBER: builtins.int
    from_port: builtins.int
    """The lowest port in the range."""
    to_port: builtins.int
    """The highest port in the range."""
    def __init__(
        self,
        *,
        from_port: builtins.int = ...,
        to_port: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["from_port", b"from_port", "to_port", b"to_port"]) -> None: ...

global___PortRange = PortRange

@typing.final
class CidrBlocks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    V4_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    V6_CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    @property
    def v4_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IPv4 CIDR blocks to allow traffic to."""

    @property
    def v6_cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IPv6 CIDR blocks to allow traffic to."""

    def __init__(
        self,
        *,
        v4_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
        v6_cidr_blocks: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["v4_cidr_blocks", b"v4_cidr_blocks", "v6_cidr_blocks", b"v6_cidr_blocks"]) -> None: ...

global___CidrBlocks = CidrBlocks



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/certificatemanager/v1/certificate_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.certificatemanager.v1 import certificate_pb2 as yandex_dot_cloud_dot_certificatemanager_dot_v1_dot_certificate__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<yandex/cloud/certificatemanager/v1/certificate_service.proto\x12\"yandex.cloud.certificatemanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/access/access.proto\x1a yandex/cloud/api/operation.proto\x1a\x34yandex/cloud/certificatemanager/v1/certificate.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"\x80\x01\n\x15GetCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x41\n\x04view\x18\x02 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateView\"\xc1\x01\n\x17ListCertificatesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x41\n\x04view\x18\x06 \x01(\x0e\x32\x33.yandex.cloud.certificatemanager.v1.CertificateViewJ\x04\x08\x04\x10\x06\"z\n\x18ListCertificatesResponse\x12\x45\n\x0c\x63\x65rtificates\x18\x01 \x03(\x0b\x32/.yandex.cloud.certificatemanager.v1.Certificate\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"y\n\x13ListVersionsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"n\n\x14ListVersionsResponse\x12=\n\x08versions\x18\x01 \x03(\x0b\x32+.yandex.cloud.certificatemanager.v1.Version\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdb\x03\n\x18\x43reateCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x95\x01\n\x06labels\x18\x04 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.CreateCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12 \n\x0b\x63\x65rtificate\x18\x05 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x06 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12%\n\x0bprivate_key\x18\x07 \x01(\tB\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08\x31-524288\x12\x1b\n\x13\x64\x65letion_protection\x18\x08 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19\x43reateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x8d\x04\n\x18UpdateCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x95\x01\n\x06labels\x18\x05 \x03(\x0b\x32H.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12 \n\x0b\x63\x65rtificate\x18\x06 \x01(\tB\x0b\x8a\xc8\x31\x07<=32768\x12\x1c\n\x05\x63hain\x18\x07 \x01(\tB\r\x8a\xc8\x31\t<=2097152\x12!\n\x0bprivate_key\x18\x08 \x01(\tB\x0c\x8a\xc8\x31\x08<=524288\x12\x1b\n\x13\x64\x65letion_protection\x18\t \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteCertificateRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xd8\x03\n\x1cRequestNewCertificateRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1024\x12\x99\x01\n\x06labels\x18\x04 \x03(\x0b\x32L.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04<=63\x12\x0f\n\x07\x64omains\x18\x05 \x03(\t\x12I\n\x0e\x63hallenge_type\x18\x06 \x01(\x0e\x32\x31.yandex.cloud.certificatemanager.v1.ChallengeType\x12\x1b\n\x13\x64\x65letion_protection\x18\x07 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x1dRequestNewCertificateMetadata\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\x86\x01\n ListCertificateOperationsRequest\x12$\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"s\n!ListCertificateOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t*&\n\x0f\x43\x65rtificateView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xca\x12\n\x12\x43\x65rtificateService\x12\xb0\x01\n\x03Get\x12\x39.yandex.cloud.certificatemanager.v1.GetCertificateRequest\x1a/.yandex.cloud.certificatemanager.v1.Certificate\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/certificate-manager/v1/certificates/{certificate_id}\x12\xaf\x01\n\x04List\x12;.yandex.cloud.certificatemanager.v1.ListCertificatesRequest\x1a<.yandex.cloud.certificatemanager.v1.ListCertificatesResponse\",\x82\xd3\xe4\x93\x02&\x12$/certificate-manager/v1/certificates\x12\xc9\x01\n\x0cListVersions\x12\x37.yandex.cloud.certificatemanager.v1.ListVersionsRequest\x1a\x38.yandex.cloud.certificatemanager.v1.ListVersionsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/certificate-manager/v1/certificates/{certificate_id}/versions\x12\xc6\x01\n\x06\x43reate\x12<.yandex.cloud.certificatemanager.v1.CreateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"[\xb2\xd2*(\n\x19\x43reateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02)\"$/certificate-manager/v1/certificates:\x01*\x12\xd7\x01\n\x06Update\x12<.yandex.cloud.certificatemanager.v1.UpdateCertificateRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*(\n\x19UpdateCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02:25/certificate-manager/v1/certificates/{certificate_id}:\x01*\x12\xd4\x01\n\x06\x44\x65lete\x12<.yandex.cloud.certificatemanager.v1.DeleteCertificateRequest\x1a!.yandex.cloud.operation.Operation\"i\xb2\xd2*(\n\x19\x44\x65leteCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02\x37*5/certificate-manager/v1/certificates/{certificate_id}\x12\xdd\x01\n\nRequestNew\x12@.yandex.cloud.certificatemanager.v1.RequestNewCertificateRequest\x1a!.yandex.cloud.operation.Operation\"j\xb2\xd2*,\n\x1dRequestNewCertificateMetadata\x12\x0b\x43\x65rtificate\x82\xd3\xe4\x93\x02\x34\"//certificate-manager/v1/certificates/requestNew:\x01*\x12\xe7\x01\n\x0eListOperations\x12\x44.yandex.cloud.certificatemanager.v1.ListCertificateOperationsRequest\x1a\x45.yandex.cloud.certificatemanager.v1.ListCertificateOperationsResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/certificate-manager/v1/certificates/{certificate_id}/operations\x12\xc4\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"M\x82\xd3\xe4\x93\x02G\x12\x45/certificate-manager/v1/certificates/{resource_id}:listAccessBindings\x12\xf4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8c\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\x01*\x12\x80\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x92\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\x01*B\x83\x01\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.certificatemanager.v1.certificate_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&yandex.cloud.api.certificatemanager.v1ZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/certificatemanager/v1;certificatemanager'
  _GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _GETCERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATESREQUEST.fields_by_name['page_size']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCERTIFICATESREQUEST.fields_by_name['page_token']._options = None
  _LISTCERTIFICATESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTVERSIONSREQUEST.fields_by_name['certificate_id']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTVERSIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATECERTIFICATEREQUEST_LABELSENTRY._options = None
  _CREATECERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATECERTIFICATEREQUEST.fields_by_name['name']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _CREATECERTIFICATEREQUEST.fields_by_name['description']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _CREATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _CREATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['certificate']._serialized_options = b'\212\3101\007<=32768'
  _CREATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['chain']._serialized_options = b'\212\3101\t<=2097152'
  _CREATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
  _CREATECERTIFICATEREQUEST.fields_by_name['private_key']._serialized_options = b'\350\3071\001\212\3101\0101-524288'
  _UPDATECERTIFICATEREQUEST_LABELSENTRY._options = None
  _UPDATECERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATECERTIFICATEREQUEST.fields_by_name['name']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATECERTIFICATEREQUEST.fields_by_name['description']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _UPDATECERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['certificate']._serialized_options = b'\212\3101\007<=32768'
  _UPDATECERTIFICATEREQUEST.fields_by_name['chain']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['chain']._serialized_options = b'\212\3101\t<=2097152'
  _UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._options = None
  _UPDATECERTIFICATEREQUEST.fields_by_name['private_key']._serialized_options = b'\212\3101\010<=524288'
  _DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._options = None
  _DELETECERTIFICATEREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._options = None
  _REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\006<=1024'
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._options = None
  _REQUESTNEWCERTIFICATEREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\004<=63'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['certificate_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCERTIFICATEOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CERTIFICATESERVICE.methods_by_name['Get']._options = None
  _CERTIFICATESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0027\0225/certificate-manager/v1/certificates/{certificate_id}'
  _CERTIFICATESERVICE.methods_by_name['List']._options = None
  _CERTIFICATESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002&\022$/certificate-manager/v1/certificates'
  _CERTIFICATESERVICE.methods_by_name['ListVersions']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListVersions']._serialized_options = b'\202\323\344\223\002@\022>/certificate-manager/v1/certificates/{certificate_id}/versions'
  _CERTIFICATESERVICE.methods_by_name['Create']._options = None
  _CERTIFICATESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateCertificateMetadata\022\013Certificate\202\323\344\223\002)\"$/certificate-manager/v1/certificates:\001*'
  _CERTIFICATESERVICE.methods_by_name['Update']._options = None
  _CERTIFICATESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateCertificateMetadata\022\013Certificate\202\323\344\223\002:25/certificate-manager/v1/certificates/{certificate_id}:\001*'
  _CERTIFICATESERVICE.methods_by_name['Delete']._options = None
  _CERTIFICATESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*(\n\031DeleteCertificateMetadata\022\013Certificate\202\323\344\223\0027*5/certificate-manager/v1/certificates/{certificate_id}'
  _CERTIFICATESERVICE.methods_by_name['RequestNew']._options = None
  _CERTIFICATESERVICE.methods_by_name['RequestNew']._serialized_options = b'\262\322*,\n\035RequestNewCertificateMetadata\022\013Certificate\202\323\344\223\0024\"//certificate-manager/v1/certificates/requestNew:\001*'
  _CERTIFICATESERVICE.methods_by_name['ListOperations']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002B\022@/certificate-manager/v1/certificates/{certificate_id}/operations'
  _CERTIFICATESERVICE.methods_by_name['ListAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002G\022E/certificate-manager/v1/certificates/{resource_id}:listAccessBindings'
  _CERTIFICATESERVICE.methods_by_name['SetAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002I\"D/certificate-manager/v1/certificates/{resource_id}:setAccessBindings:\001*'
  _CERTIFICATESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _CERTIFICATESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002L\"G/certificate-manager/v1/certificates/{resource_id}:updateAccessBindings:\001*'
  _globals['_CERTIFICATEVIEW']._serialized_start=3060
  _globals['_CERTIFICATEVIEW']._serialized_end=3098
  _globals['_GETCERTIFICATEREQUEST']._serialized_start=358
  _globals['_GETCERTIFICATEREQUEST']._serialized_end=486
  _globals['_LISTCERTIFICATESREQUEST']._serialized_start=489
  _globals['_LISTCERTIFICATESREQUEST']._serialized_end=682
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_start=684
  _globals['_LISTCERTIFICATESRESPONSE']._serialized_end=806
  _globals['_LISTVERSIONSREQUEST']._serialized_start=808
  _globals['_LISTVERSIONSREQUEST']._serialized_end=929
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=931
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=1041
  _globals['_CREATECERTIFICATEREQUEST']._serialized_start=1044
  _globals['_CREATECERTIFICATEREQUEST']._serialized_end=1519
  _globals['_CREATECERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_CREATECERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_CREATECERTIFICATEMETADATA']._serialized_start=1521
  _globals['_CREATECERTIFICATEMETADATA']._serialized_end=1572
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_start=1575
  _globals['_UPDATECERTIFICATEREQUEST']._serialized_end=2100
  _globals['_UPDATECERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_UPDATECERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_start=2102
  _globals['_UPDATECERTIFICATEMETADATA']._serialized_end=2153
  _globals['_DELETECERTIFICATEREQUEST']._serialized_start=2155
  _globals['_DELETECERTIFICATEREQUEST']._serialized_end=2219
  _globals['_DELETECERTIFICATEMETADATA']._serialized_start=2221
  _globals['_DELETECERTIFICATEMETADATA']._serialized_end=2272
  _globals['_REQUESTNEWCERTIFICATEREQUEST']._serialized_start=2275
  _globals['_REQUESTNEWCERTIFICATEREQUEST']._serialized_end=2747
  _globals['_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY']._serialized_start=1474
  _globals['_REQUESTNEWCERTIFICATEREQUEST_LABELSENTRY']._serialized_end=1519
  _globals['_REQUESTNEWCERTIFICATEMETADATA']._serialized_start=2749
  _globals['_REQUESTNEWCERTIFICATEMETADATA']._serialized_end=2804
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_start=2807
  _globals['_LISTCERTIFICATEOPERATIONSREQUEST']._serialized_end=2941
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_start=2943
  _globals['_LISTCERTIFICATEOPERATIONSRESPONSE']._serialized_end=3058
  _globals['_CERTIFICATESERVICE']._serialized_start=3101
  _globals['_CERTIFICATESERVICE']._serialized_end=5479
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report/table/report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.common import quantiles_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_common_dot_quantiles__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/loadtesting/api/v1/report/table/report.proto\x12,yandex.cloud.loadtesting.api.v1.report.table\x1a\x36yandex/cloud/loadtesting/api/v1/common/quantiles.proto\"\xe1\x02\n\x06Report\x12W\n\nhttp_codes\x18\x01 \x03(\x0b\x32\x43.yandex.cloud.loadtesting.api.v1.report.table.Report.HttpCodesEntry\x12U\n\tnet_codes\x18\x02 \x03(\x0b\x32\x42.yandex.cloud.loadtesting.api.v1.report.table.Report.NetCodesEntry\x12\x44\n\tquantiles\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.loadtesting.api.v1.common.Quantiles\x1a\x30\n\x0eHttpCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a/\n\rNetCodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x42\x8a\x01\n0yandex.cloud.api.loadtesting.api.v1.report.tableZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report/table;tableb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report.table.report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n0yandex.cloud.api.loadtesting.api.v1.report.tableZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report/table;table'
  _REPORT_HTTPCODESENTRY._options = None
  _REPORT_HTTPCODESENTRY._serialized_options = b'8\001'
  _REPORT_NETCODESENTRY._options = None
  _REPORT_NETCODESENTRY._serialized_options = b'8\001'
  _globals['_REPORT']._serialized_start=164
  _globals['_REPORT']._serialized_end=517
  _globals['_REPORT_HTTPCODESENTRY']._serialized_start=420
  _globals['_REPORT_HTTPCODESENTRY']._serialized_end=468
  _globals['_REPORT_NETCODESENTRY']._serialized_start=470
  _globals['_REPORT_NETCODESENTRY']._serialized_end=517
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/jobs/project_job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.datasphere.v2.jobs import jobs_pb2 as yandex_dot_cloud_dot_datasphere_dot_v2_dot_jobs_dot_jobs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9yandex/cloud/datasphere/v2/jobs/project_job_service.proto\x12\x1fyandex.cloud.datasphere.v2.jobs\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a*yandex/cloud/datasphere/v2/jobs/jobs.proto\"\xce\x01\n\x17\x43reateProjectJobRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x46\n\x0ejob_parameters\x18\x02 \x01(\x0b\x32..yandex.cloud.datasphere.v2.jobs.JobParameters\x12\x0e\n\x06\x63onfig\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x05 \x01(\t\x12+\n\x08\x64\x61ta_ttl\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\">\n\x18\x43reateProjectJobMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"n\n\x18\x43reateProjectJobResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x42\n\x0cupload_files\x18\x02 \x03(\x0b\x32,.yandex.cloud.datasphere.v2.jobs.StorageFile\"\xca\x01\n\x16\x43loneProjectJobRequest\x12\x15\n\rsource_job_id\x18\x01 \x01(\t\x12P\n\x18job_parameters_overrides\x18\x02 \x01(\x0b\x32..yandex.cloud.datasphere.v2.jobs.JobParameters\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x04 \x01(\t\x12+\n\x08\x64\x61ta_ttl\x18\x05 \x01(\x0b\x32\x19.google.protobuf.Duration\"m\n\x17\x43loneProjectJobResponse\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x42\n\x0cupload_files\x18\x02 \x03(\x0b\x32,.yandex.cloud.datasphere.v2.jobs.StorageFile\"=\n\x17\x43loneProjectJobMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06job_id\x18\x02 \x01(\t\"*\n\x18\x45xecuteProjectJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xe4\x01\n\x19\x45xecuteProjectJobResponse\x12\x42\n\x0coutput_files\x18\x01 \x03(\x0b\x32,.yandex.cloud.datasphere.v2.jobs.StorageFile\x12G\n\x0foutput_datasets\x18\x03 \x03(\x0b\x32..yandex.cloud.datasphere.v2.jobs.OutputDataset\x12:\n\x06result\x18\x02 \x01(\x0b\x32*.yandex.cloud.datasphere.v2.jobs.JobResult\"N\n\x19\x45xecuteProjectJobMetadata\x12\x31\n\x03job\x18\x01 \x01(\x0b\x32$.yandex.cloud.datasphere.v2.jobs.Job\"9\n\x17\x43\x61ncelProjectJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\">\n\x1cReadProjectJobStdLogsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"f\n\x1dReadProjectJobStdLogsResponse\x12\x35\n\x04logs\x18\x01 \x03(\x0b\x32\'.yandex.cloud.datasphere.v2.jobs.StdLog\x12\x0e\n\x06offset\x18\x02 \x01(\x03\";\n\x19ReadProjectJobLogsRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"g\n\x1aReadProjectJobLogsResponse\x12\x39\n\x04logs\x18\x01 \x03(\x0b\x32+.yandex.cloud.datasphere.v2.jobs.LogMessage\x12\x0e\n\x06offset\x18\x02 \x01(\x03\"u\n\x1e\x44ownloadProjectJobFilesRequest\x12\x14\n\x06job_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12=\n\x05\x66iles\x18\x02 \x03(\x0b\x32%.yandex.cloud.datasphere.v2.jobs.FileB\x07\x82\xc8\x31\x03>=1\"g\n\x1f\x44ownloadProjectJobFilesResponse\x12\x44\n\x0e\x64ownload_files\x18\x01 \x03(\x0b\x32,.yandex.cloud.datasphere.v2.jobs.StorageFile\"n\n\x15ListProjectJobRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x03\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"e\n\x16ListProjectJobResponse\x12\x32\n\x04jobs\x18\x01 \x03(\x0b\x32$.yandex.cloud.datasphere.v2.jobs.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"&\n\x14GetProjectJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\")\n\x17\x44\x65leteProjectJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"*\n\x18\x44\x65leteProjectJobMetadata\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"-\n\x1b\x44\x65leteProjectJobDataRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\".\n\x1c\x44\x65leteProjectJobDataMetadata\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\x1e\n\x1c\x44\x65leteProjectJobDataResponse\"4\n\x1e\x44\x65leteAllProjectJobDataRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"5\n\x1f\x44\x65leteAllProjectJobDataMetadata\x12\x12\n\nproject_id\x18\x01 \x01(\t\"!\n\x1f\x44\x65leteAllProjectJobDataResponse\"U\n\x1bSetProjectJobDataTtlRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12&\n\x03ttl\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x1e\n\x1cSetProjectJobDataTtlResponse\"\x85\x01\n\x06StdLog\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12:\n\x04type\x18\x02 \x01(\x0e\x32,.yandex.cloud.datasphere.v2.jobs.StdLog.Type\".\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03OUT\x10\x01\x12\x07\n\x03\x45RR\x10\x02\"\xb8\x01\n\nLogMessage\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12J\n\x0fstandard_stream\x18\x03 \x01(\x0e\x32/.yandex.cloud.datasphere.v2.jobs.StandardStreamH\x00\x12\x13\n\tfile_path\x18\x04 \x01(\tH\x00\x42\x08\n\x06source*C\n\x0eStandardStream\x12\x1f\n\x1bSTANDARD_STREAM_UNSPECIFIED\x10\x00\x12\x07\n\x03OUT\x10\x01\x12\x07\n\x03\x45RR\x10\x02\x32\x83\x0f\n\x11ProjectJobService\x12\x9f\x01\n\x06\x43reate\x12\x38.yandex.cloud.datasphere.v2.jobs.CreateProjectJobRequest\x1a!.yandex.cloud.operation.Operation\"8\xb2\xd2*4\n\x18\x43reateProjectJobMetadata\x12\x18\x43reateProjectJobResponse\x12\x9b\x01\n\x05\x43lone\x12\x37.yandex.cloud.datasphere.v2.jobs.CloneProjectJobRequest\x1a!.yandex.cloud.operation.Operation\"6\xb2\xd2*2\n\x17\x43loneProjectJobMetadata\x12\x17\x43loneProjectJobResponse\x12\xa3\x01\n\x07\x45xecute\x12\x39.yandex.cloud.datasphere.v2.jobs.ExecuteProjectJobRequest\x1a!.yandex.cloud.operation.Operation\":\xb2\xd2*6\n\x19\x45xecuteProjectJobMetadata\x12\x19\x45xecuteProjectJobResponse\x12Z\n\x06\x43\x61ncel\x12\x38.yandex.cloud.datasphere.v2.jobs.CancelProjectJobRequest\x1a\x16.google.protobuf.Empty\x12\x93\x01\n\x0bReadStdLogs\x12=.yandex.cloud.datasphere.v2.jobs.ReadProjectJobStdLogsRequest\x1a>.yandex.cloud.datasphere.v2.jobs.ReadProjectJobStdLogsResponse\"\x03\x88\x02\x01\x30\x01\x12\x85\x01\n\x08ReadLogs\x12:.yandex.cloud.datasphere.v2.jobs.ReadProjectJobLogsRequest\x1a;.yandex.cloud.datasphere.v2.jobs.ReadProjectJobLogsResponse0\x01\x12\x95\x01\n\x10\x44ownloadJobFiles\x12?.yandex.cloud.datasphere.v2.jobs.DownloadProjectJobFilesRequest\x1a@.yandex.cloud.datasphere.v2.jobs.DownloadProjectJobFilesResponse\x12w\n\x04List\x12\x36.yandex.cloud.datasphere.v2.jobs.ListProjectJobRequest\x1a\x37.yandex.cloud.datasphere.v2.jobs.ListProjectJobResponse\x12\x62\n\x03Get\x12\x35.yandex.cloud.datasphere.v2.jobs.GetProjectJobRequest\x1a$.yandex.cloud.datasphere.v2.jobs.Job\x12\x9c\x01\n\x06\x44\x65lete\x12\x38.yandex.cloud.datasphere.v2.jobs.DeleteProjectJobRequest\x1a!.yandex.cloud.operation.Operation\"5\xb2\xd2*1\n\x18\x44\x65leteProjectJobMetadata\x12\x15google.protobuf.Empty\x12\xaf\x01\n\nDeleteData\x12<.yandex.cloud.datasphere.v2.jobs.DeleteProjectJobDataRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n\x1c\x44\x65leteProjectJobDataMetadata\x12\x1c\x44\x65leteProjectJobDataResponse\x12\xbb\x01\n\rDeleteAllData\x12?.yandex.cloud.datasphere.v2.jobs.DeleteAllProjectJobDataRequest\x1a!.yandex.cloud.operation.Operation\"F\xb2\xd2*B\n\x1f\x44\x65leteAllProjectJobDataMetadata\x12\x1f\x44\x65leteAllProjectJobDataResponse\x12\x89\x01\n\nSetDataTtl\x12<.yandex.cloud.datasphere.v2.jobs.SetProjectJobDataTtlRequest\x1a=.yandex.cloud.datasphere.v2.jobs.SetProjectJobDataTtlResponseB|\n#yandex.cloud.api.datasphere.v2.jobsB\x05\x44SPJSZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2/jobs;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.jobs.project_job_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.datasphere.v2.jobsB\005DSPJSZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2/jobs;datasphere'
  _DOWNLOADPROJECTJOBFILESREQUEST.fields_by_name['job_id']._options = None
  _DOWNLOADPROJECTJOBFILESREQUEST.fields_by_name['job_id']._serialized_options = b'\350\3071\001'
  _DOWNLOADPROJECTJOBFILESREQUEST.fields_by_name['files']._options = None
  _DOWNLOADPROJECTJOBFILESREQUEST.fields_by_name['files']._serialized_options = b'\202\3101\003>=1'
  _LISTPROJECTJOBREQUEST.fields_by_name['filter']._options = None
  _LISTPROJECTJOBREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _PROJECTJOBSERVICE.methods_by_name['Create']._options = None
  _PROJECTJOBSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*4\n\030CreateProjectJobMetadata\022\030CreateProjectJobResponse'
  _PROJECTJOBSERVICE.methods_by_name['Clone']._options = None
  _PROJECTJOBSERVICE.methods_by_name['Clone']._serialized_options = b'\262\322*2\n\027CloneProjectJobMetadata\022\027CloneProjectJobResponse'
  _PROJECTJOBSERVICE.methods_by_name['Execute']._options = None
  _PROJECTJOBSERVICE.methods_by_name['Execute']._serialized_options = b'\262\322*6\n\031ExecuteProjectJobMetadata\022\031ExecuteProjectJobResponse'
  _PROJECTJOBSERVICE.methods_by_name['ReadStdLogs']._options = None
  _PROJECTJOBSERVICE.methods_by_name['ReadStdLogs']._serialized_options = b'\210\002\001'
  _PROJECTJOBSERVICE.methods_by_name['Delete']._options = None
  _PROJECTJOBSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteProjectJobMetadata\022\025google.protobuf.Empty'
  _PROJECTJOBSERVICE.methods_by_name['DeleteData']._options = None
  _PROJECTJOBSERVICE.methods_by_name['DeleteData']._serialized_options = b'\262\322*<\n\034DeleteProjectJobDataMetadata\022\034DeleteProjectJobDataResponse'
  _PROJECTJOBSERVICE.methods_by_name['DeleteAllData']._options = None
  _PROJECTJOBSERVICE.methods_by_name['DeleteAllData']._serialized_options = b'\262\322*B\n\037DeleteAllProjectJobDataMetadata\022\037DeleteAllProjectJobDataResponse'
  _globals['_STANDARDSTREAM']._serialized_start=3128
  _globals['_STANDARDSTREAM']._serialized_end=3195
  _globals['_CREATEPROJECTJOBREQUEST']._serialized_start=338
  _globals['_CREATEPROJECTJOBREQUEST']._serialized_end=544
  _globals['_CREATEPROJECTJOBMETADATA']._serialized_start=546
  _globals['_CREATEPROJECTJOBMETADATA']._serialized_end=608
  _globals['_CREATEPROJECTJOBRESPONSE']._serialized_start=610
  _globals['_CREATEPROJECTJOBRESPONSE']._serialized_end=720
  _globals['_CLONEPROJECTJOBREQUEST']._serialized_start=723
  _globals['_CLONEPROJECTJOBREQUEST']._serialized_end=925
  _globals['_CLONEPROJECTJOBRESPONSE']._serialized_start=927
  _globals['_CLONEPROJECTJOBRESPONSE']._serialized_end=1036
  _globals['_CLONEPROJECTJOBMETADATA']._serialized_start=1038
  _globals['_CLONEPROJECTJOBMETADATA']._serialized_end=1099
  _globals['_EXECUTEPROJECTJOBREQUEST']._serialized_start=1101
  _globals['_EXECUTEPROJECTJOBREQUEST']._serialized_end=1143
  _globals['_EXECUTEPROJECTJOBRESPONSE']._serialized_start=1146
  _globals['_EXECUTEPROJECTJOBRESPONSE']._serialized_end=1374
  _globals['_EXECUTEPROJECTJOBMETADATA']._serialized_start=1376
  _globals['_EXECUTEPROJECTJOBMETADATA']._serialized_end=1454
  _globals['_CANCELPROJECTJOBREQUEST']._serialized_start=1456
  _globals['_CANCELPROJECTJOBREQUEST']._serialized_end=1513
  _globals['_READPROJECTJOBSTDLOGSREQUEST']._serialized_start=1515
  _globals['_READPROJECTJOBSTDLOGSREQUEST']._serialized_end=1577
  _globals['_READPROJECTJOBSTDLOGSRESPONSE']._serialized_start=1579
  _globals['_READPROJECTJOBSTDLOGSRESPONSE']._serialized_end=1681
  _globals['_READPROJECTJOBLOGSREQUEST']._serialized_start=1683
  _globals['_READPROJECTJOBLOGSREQUEST']._serialized_end=1742
  _globals['_READPROJECTJOBLOGSRESPONSE']._serialized_start=1744
  _globals['_READPROJECTJOBLOGSRESPONSE']._serialized_end=1847
  _globals['_DOWNLOADPROJECTJOBFILESREQUEST']._serialized_start=1849
  _globals['_DOWNLOADPROJECTJOBFILESREQUEST']._serialized_end=1966
  _globals['_DOWNLOADPROJECTJOBFILESRESPONSE']._serialized_start=1968
  _globals['_DOWNLOADPROJECTJOBFILESRESPONSE']._serialized_end=2071
  _globals['_LISTPROJECTJOBREQUEST']._serialized_start=2073
  _globals['_LISTPROJECTJOBREQUEST']._serialized_end=2183
  _globals['_LISTPROJECTJOBRESPONSE']._serialized_start=2185
  _globals['_LISTPROJECTJOBRESPONSE']._serialized_end=2286
  _globals['_GETPROJECTJOBREQUEST']._serialized_start=2288
  _globals['_GETPROJECTJOBREQUEST']._serialized_end=2326
  _globals['_DELETEPROJECTJOBREQUEST']._serialized_start=2328
  _globals['_DELETEPROJECTJOBREQUEST']._serialized_end=2369
  _globals['_DELETEPROJECTJOBMETADATA']._serialized_start=2371
  _globals['_DELETEPROJECTJOBMETADATA']._serialized_end=2413
  _globals['_DELETEPROJECTJOBDATAREQUEST']._serialized_start=2415
  _globals['_DELETEPROJECTJOBDATAREQUEST']._serialized_end=2460
  _globals['_DELETEPROJECTJOBDATAMETADATA']._serialized_start=2462
  _globals['_DELETEPROJECTJOBDATAMETADATA']._serialized_end=2508
  _globals['_DELETEPROJECTJOBDATARESPONSE']._serialized_start=2510
  _globals['_DELETEPROJECTJOBDATARESPONSE']._serialized_end=2540
  _globals['_DELETEALLPROJECTJOBDATAREQUEST']._serialized_start=2542
  _globals['_DELETEALLPROJECTJOBDATAREQUEST']._serialized_end=2594
  _globals['_DELETEALLPROJECTJOBDATAMETADATA']._serialized_start=2596
  _globals['_DELETEALLPROJECTJOBDATAMETADATA']._serialized_end=2649
  _globals['_DELETEALLPROJECTJOBDATARESPONSE']._serialized_start=2651
  _globals['_DELETEALLPROJECTJOBDATARESPONSE']._serialized_end=2684
  _globals['_SETPROJECTJOBDATATTLREQUEST']._serialized_start=2686
  _globals['_SETPROJECTJOBDATATTLREQUEST']._serialized_end=2771
  _globals['_SETPROJECTJOBDATATTLRESPONSE']._serialized_start=2773
  _globals['_SETPROJECTJOBDATATTLRESPONSE']._serialized_end=2803
  _globals['_STDLOG']._serialized_start=2806
  _globals['_STDLOG']._serialized_end=2939
  _globals['_STDLOG_TYPE']._serialized_start=2893
  _globals['_STDLOG_TYPE']._serialized_end=2939
  _globals['_LOGMESSAGE']._serialized_start=2942
  _globals['_LOGMESSAGE']._serialized_end=3126
  _globals['_PROJECTJOBSERVICE']._serialized_start=3198
  _globals['_PROJECTJOBSERVICE']._serialized_end=5121
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ResourceType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ResourceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ResourceType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESOURCE_TYPE_UNSPECIFIED: _ResourceType.ValueType  # 0
    COMPUTE: _ResourceType.ValueType  # 1
    """Resource is Compute Cloud VM"""
    BMS: _ResourceType.ValueType  # 2
    """Resource is baremetal server"""

class ResourceType(_ResourceType, metaclass=_ResourceTypeEnumTypeWrapper): ...

RESOURCE_TYPE_UNSPECIFIED: ResourceType.ValueType  # 0
COMPUTE: ResourceType.ValueType  # 1
"""Resource is Compute Cloud VM"""
BMS: ResourceType.ValueType  # 2
"""Resource is baremetal server"""
global___ResourceType = ResourceType

@typing.final
class Resource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Resource._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Resource._Status.ValueType  # 0
        IDLE: Resource._Status.ValueType  # 1
        """Compute Cloud instance is doing nothing right now."""
        BACKUPING: Resource._Status.ValueType  # 2
        """Compute Cloud instance is currently backing up itself."""
        RECOVERING: Resource._Status.ValueType  # 3
        """Compute Cloud instance is currently recovering itself."""
        FAILED: Resource._Status.ValueType  # 4
        """Compute Cloud instance is in failure state, check content of 
        `status_details` field for more information.
        """
        OTHER: Resource._Status.ValueType  # 5
        """Unspecified state, check `status_details` field
        for more information.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Resource.Status.ValueType  # 0
    IDLE: Resource.Status.ValueType  # 1
    """Compute Cloud instance is doing nothing right now."""
    BACKUPING: Resource.Status.ValueType  # 2
    """Compute Cloud instance is currently backing up itself."""
    RECOVERING: Resource.Status.ValueType  # 3
    """Compute Cloud instance is currently recovering itself."""
    FAILED: Resource.Status.ValueType  # 4
    """Compute Cloud instance is in failure state, check content of 
    `status_details` field for more information.
    """
    OTHER: Resource.Status.ValueType  # 5
    """Unspecified state, check `status_details` field
    for more information.
    """

    class _InitStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _InitStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Resource._InitStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        INIT_STATUS_UNSPECIFIED: Resource._InitStatus.ValueType  # 0
        REGISTERING: Resource._InitStatus.ValueType  # 1
        """Registration of instance in cloud backups have started."""
        REGISTRED: Resource._InitStatus.ValueType  # 2
        """Instance is registered in cloud backups."""
        FAILED_REGISTRATION: Resource._InitStatus.ValueType  # 3
        """Instance registration failed."""
        DELETED: Resource._InitStatus.ValueType  # 4
        """Instance is deleted from cloud backup service."""

    class InitStatus(_InitStatus, metaclass=_InitStatusEnumTypeWrapper): ...
    INIT_STATUS_UNSPECIFIED: Resource.InitStatus.ValueType  # 0
    REGISTERING: Resource.InitStatus.ValueType  # 1
    """Registration of instance in cloud backups have started."""
    REGISTRED: Resource.InitStatus.ValueType  # 2
    """Instance is registered in cloud backups."""
    FAILED_REGISTRATION: Resource.InitStatus.ValueType  # 3
    """Instance registration failed."""
    DELETED: Resource.InitStatus.ValueType  # 4
    """Instance is deleted from cloud backup service."""

    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    ONLINE_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    STATUS_DETAILS_FIELD_NUMBER: builtins.int
    STATUS_PROGRESS_FIELD_NUMBER: builtins.int
    LAST_BACKUP_TIME_FIELD_NUMBER: builtins.int
    NEXT_BACKUP_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    IS_ACTIVE_FIELD_NUMBER: builtins.int
    INIT_STATUS_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    online: builtins.bool
    """If this field is true, it means that instance is online."""
    enabled: builtins.bool
    """If this field is true, it means that backup is enabled to instance."""
    status: global___Resource.Status.ValueType
    status_details: builtins.str
    """If status value is one of `OTHER` or `FAILED`,
    detailed info might be stored here.
    """
    status_progress: builtins.int
    """In case status is one of `BACKUPING` or `RECOVERING`,
    progress value might be found here.
    """
    resource_id: builtins.str
    """Resource ID is used to identify Compute Cloud instance in backup service."""
    is_active: builtins.bool
    """Status `is_active` shows whether current Compute Cloud instance controls Cloud Backup resource.
    If status `is_active` is false it means Compute Cloud instance is not able to manipulate
    Cloud Backup resource.
    """
    init_status: global___Resource.InitStatus.ValueType
    """Status of resource initialization in cloud backup service."""
    metadata: builtins.str
    """Metadata to provide details about instance registration process
    if status is FAILED_REGISTRATION or REGISTERING
    """
    type: global___ResourceType.ValueType
    """Type of resource -- could be compute VM or baremetal server"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def last_backup_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def next_backup_time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        compute_instance_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        online: builtins.bool = ...,
        enabled: builtins.bool = ...,
        status: global___Resource.Status.ValueType = ...,
        status_details: builtins.str = ...,
        status_progress: builtins.int = ...,
        last_backup_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        next_backup_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        resource_id: builtins.str = ...,
        is_active: builtins.bool = ...,
        init_status: global___Resource.InitStatus.ValueType = ...,
        metadata: builtins.str = ...,
        type: global___ResourceType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "last_backup_time", b"last_backup_time", "next_backup_time", b"next_backup_time", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["compute_instance_id", b"compute_instance_id", "created_at", b"created_at", "enabled", b"enabled", "init_status", b"init_status", "is_active", b"is_active", "last_backup_time", b"last_backup_time", "metadata", b"metadata", "next_backup_time", b"next_backup_time", "online", b"online", "resource_id", b"resource_id", "status", b"status", "status_details", b"status_details", "status_progress", b"status_progress", "type", b"type", "updated_at", b"updated_at"]) -> None: ...

global___Resource = Resource

@typing.final
class Progress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    current: builtins.int
    total: builtins.int
    def __init__(
        self,
        *,
        current: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current", b"current", "total", b"total"]) -> None: ...

global___Progress = Progress

@typing.final
class Task(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Task._Type.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        TYPE_UNSPECIFIED: Task._Type.ValueType  # 0
        BACKUP: Task._Type.ValueType  # 1
        RETENTION: Task._Type.ValueType  # 2
        RECOVERY: Task._Type.ValueType  # 3

    class Type(_Type, metaclass=_TypeEnumTypeWrapper): ...
    TYPE_UNSPECIFIED: Task.Type.ValueType  # 0
    BACKUP: Task.Type.ValueType  # 1
    RETENTION: Task.Type.ValueType  # 2
    RECOVERY: Task.Type.ValueType  # 3

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Task._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Task._Status.ValueType  # 0
        ENQUEUED: Task._Status.ValueType  # 1
        ASSIGNED: Task._Status.ValueType  # 2
        STARTED: Task._Status.ValueType  # 3
        PAUSED: Task._Status.ValueType  # 4
        COMPLETED: Task._Status.ValueType  # 5

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Status of task."""

    STATUS_UNSPECIFIED: Task.Status.ValueType  # 0
    ENQUEUED: Task.Status.ValueType  # 1
    ASSIGNED: Task.Status.ValueType  # 2
    STARTED: Task.Status.ValueType  # 3
    PAUSED: Task.Status.ValueType  # 4
    COMPLETED: Task.Status.ValueType  # 5

    class _Code:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Task._Code.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CODE_UNSPECIFIED: Task._Code.ValueType  # 0
        OK: Task._Code.ValueType  # 1
        ERROR: Task._Code.ValueType  # 2
        WARNING: Task._Code.ValueType  # 3
        CANCELLED: Task._Code.ValueType  # 4
        ABANDONED: Task._Code.ValueType  # 5
        TIMEDOUT: Task._Code.ValueType  # 6

    class Code(_Code, metaclass=_CodeEnumTypeWrapper):
        """Result code of task"""

    CODE_UNSPECIFIED: Task.Code.ValueType  # 0
    OK: Task.Code.ValueType  # 1
    ERROR: Task.Code.ValueType  # 2
    WARNING: Task.Code.ValueType  # 3
    CANCELLED: Task.Code.ValueType  # 4
    ABANDONED: Task.Code.ValueType  # 5
    TIMEDOUT: Task.Code.ValueType  # 6

    ID_FIELD_NUMBER: builtins.int
    CANCELLABLE_FIELD_NUMBER: builtins.int
    POLICY_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ENQUEUED_AT_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    COMPLETED_AT_FIELD_NUMBER: builtins.int
    COMPUTE_INSTANCE_ID_FIELD_NUMBER: builtins.int
    RESULT_CODE_FIELD_NUMBER: builtins.int
    id: builtins.int
    """Task ID."""
    cancellable: builtins.bool
    """Shows whether the task is cancellable.
    Note: task cancellation is not supported yet.
    """
    policy_id: builtins.str
    """Policy ID."""
    type: global___Task.Type.ValueType
    """Type of the task."""
    status: global___Task.Status.ValueType
    """Task status."""
    compute_instance_id: builtins.str
    """Compute Cloud instance ID."""
    result_code: global___Task.Code.ValueType
    """Task result code."""
    @property
    def progress(self) -> global___Progress:
        """Task progress."""

    @property
    def enqueued_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def completed_at(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        cancellable: builtins.bool = ...,
        policy_id: builtins.str = ...,
        type: global___Task.Type.ValueType = ...,
        progress: global___Progress | None = ...,
        status: global___Task.Status.ValueType = ...,
        enqueued_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        completed_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        compute_instance_id: builtins.str = ...,
        result_code: global___Task.Code.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["completed_at", b"completed_at", "enqueued_at", b"enqueued_at", "progress", b"progress", "started_at", b"started_at", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cancellable", b"cancellable", "completed_at", b"completed_at", "compute_instance_id", b"compute_instance_id", "enqueued_at", b"enqueued_at", "id", b"id", "policy_id", b"policy_id", "progress", b"progress", "result_code", b"result_code", "started_at", b"started_at", "status", b"status", "type", b"type", "updated_at", b"updated_at"]) -> None: ...

global___Task = Task



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/disk_type_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.compute.v1 import disk_type_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__type__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/yandex/cloud/compute/v1/disk_type_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a\'yandex/cloud/compute/v1/disk_type.proto\x1a\x1dyandex/cloud/validation.proto\"0\n\x12GetDiskTypeRequest\x12\x1a\n\x0c\x64isk_type_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"T\n\x14ListDiskTypesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x15ListDiskTypesResponse\x12\x35\n\ndisk_types\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.DiskType\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x9e\x02\n\x0f\x44iskTypeService\x12\x83\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetDiskTypeRequest\x1a!.yandex.cloud.compute.v1.DiskType\",\x82\xd3\xe4\x93\x02&\x12$/compute/v1/diskTypes/{disk_type_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListDiskTypesRequest\x1a..yandex.cloud.compute.v1.ListDiskTypesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/diskTypesBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.compute.v1.disk_type_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute'
  _GETDISKTYPEREQUEST.fields_by_name['disk_type_id']._options = None
  _GETDISKTYPEREQUEST.fields_by_name['disk_type_id']._serialized_options = b'\350\3071\001'
  _LISTDISKTYPESREQUEST.fields_by_name['page_size']._options = None
  _LISTDISKTYPESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTDISKTYPESREQUEST.fields_by_name['page_token']._options = None
  _LISTDISKTYPESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _DISKTYPESERVICE.methods_by_name['Get']._options = None
  _DISKTYPESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002&\022$/compute/v1/diskTypes/{disk_type_id}'
  _DISKTYPESERVICE.methods_by_name['List']._options = None
  _DISKTYPESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\027\022\025/compute/v1/diskTypes'
  _globals['_GETDISKTYPEREQUEST']._serialized_start=178
  _globals['_GETDISKTYPEREQUEST']._serialized_end=226
  _globals['_LISTDISKTYPESREQUEST']._serialized_start=228
  _globals['_LISTDISKTYPESREQUEST']._serialized_end=312
  _globals['_LISTDISKTYPESRESPONSE']._serialized_start=314
  _globals['_LISTDISKTYPESRESPONSE']._serialized_end=417
  _globals['_DISKTYPESERVICE']._serialized_start=420
  _globals['_DISKTYPESERVICE']._serialized_end=706
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class VersionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CURRENT_VERSION_FIELD_NUMBER: builtins.int
    NEW_REVISION_AVAILABLE_FIELD_NUMBER: builtins.int
    NEW_REVISION_SUMMARY_FIELD_NUMBER: builtins.int
    VERSION_DEPRECATED_FIELD_NUMBER: builtins.int
    current_version: builtins.str
    """Current Kubernetes version, format: major.minor (e.g. 1.15)."""
    new_revision_available: builtins.bool
    """Newer revisions may include Kubernetes patches (e.g 1.15.1 -> 1.15.2) as well
    as some internal component updates - new features or bug fixes in platform specific
    components either on the master or nodes.
    """
    new_revision_summary: builtins.str
    """Description of the changes to be applied when updating to the latest
    revision. Empty if new_revision_available is false.
    """
    version_deprecated: builtins.bool
    """The current version is on the deprecation schedule, component (master or node group)
    should be upgraded.
    """
    def __init__(
        self,
        *,
        current_version: builtins.str = ...,
        new_revision_available: builtins.bool = ...,
        new_revision_summary: builtins.str = ...,
        version_deprecated: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["current_version", b"current_version", "new_revision_available", b"new_revision_available", "new_revision_summary", b"new_revision_summary", "version_deprecated", b"version_deprecated"]) -> None: ...

global___VersionInfo = VersionInfo

@typing.final
class UpdateVersionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VERSION_FIELD_NUMBER: builtins.int
    LATEST_REVISION_FIELD_NUMBER: builtins.int
    version: builtins.str
    """Request update to a newer version of Kubernetes (1.x -> 1.y)."""
    latest_revision: builtins.bool
    """Request update to the latest revision for the current version."""
    def __init__(
        self,
        *,
        version: builtins.str = ...,
        latest_revision: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["latest_revision", b"latest_revision", "specifier", b"specifier", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["latest_revision", b"latest_revision", "specifier", b"specifier", "version", b"version"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["specifier", b"specifier"]) -> typing.Literal["version", "latest_revision"] | None: ...

global___UpdateVersionSpec = UpdateVersionSpec



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateIamTokenRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    YANDEX_PASSPORT_OAUTH_TOKEN_FIELD_NUMBER: builtins.int
    JWT_FIELD_NUMBER: builtins.int
    yandex_passport_oauth_token: builtins.str
    """OAuth token for a Yandex account.
    For more information, see [OAuth token](/docs/iam/concepts/authorization/oauth-token).
    """
    jwt: builtins.str
    """JSON Web Token (JWT) for a service account.
    For more information, see [Get IAM token for a service account](/docs/iam/operations/iam-token/create-for-sa).
    """
    def __init__(
        self,
        *,
        yandex_passport_oauth_token: builtins.str = ...,
        jwt: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["identity", b"identity", "jwt", b"jwt", "yandex_passport_oauth_token", b"yandex_passport_oauth_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["identity", b"identity", "jwt", b"jwt", "yandex_passport_oauth_token", b"yandex_passport_oauth_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["identity", b"identity"]) -> typing.Literal["yandex_passport_oauth_token", "jwt"] | None: ...

global___CreateIamTokenRequest = CreateIamTokenRequest

@typing.final
class CreateIamTokenResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IAM_TOKEN_FIELD_NUMBER: builtins.int
    EXPIRES_AT_FIELD_NUMBER: builtins.int
    iam_token: builtins.str
    """IAM token for the specified identity.

    You should pass the token in the `Authorization` header for any further API requests.
    For example, `Authorization: Bearer [iam_token]`.
    """
    @property
    def expires_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """IAM token expiration time."""

    def __init__(
        self,
        *,
        iam_token: builtins.str = ...,
        expires_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["expires_at", b"expires_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["expires_at", b"expires_at", "iam_token", b"iam_token"]) -> None: ...

global___CreateIamTokenResponse = CreateIamTokenResponse

@typing.final
class CreateIamTokenForServiceAccountRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    service_account_id: builtins.str
    def __init__(
        self,
        *,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["service_account_id", b"service_account_id"]) -> None: ...

global___CreateIamTokenForServiceAccountRequest = CreateIamTokenForServiceAccountRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _GpuInterconnectType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _GpuInterconnectTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_GpuInterconnectType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    GPU_INTERCONNECT_TYPE_UNSPECIFIED: _GpuInterconnectType.ValueType  # 0
    INFINIBAND: _GpuInterconnectType.ValueType  # 1
    """InfiniBand interconnect."""

class GpuInterconnectType(_GpuInterconnectType, metaclass=_GpuInterconnectTypeEnumTypeWrapper): ...

GPU_INTERCONNECT_TYPE_UNSPECIFIED: GpuInterconnectType.ValueType  # 0
INFINIBAND: GpuInterconnectType.ValueType  # 1
"""InfiniBand interconnect."""
global___GpuInterconnectType = GpuInterconnectType

@typing.final
class GpuCluster(google.protobuf.message.Message):
    """A GPU cluster. For details about the concept, see [documentation](/docs/compute/concepts/gpu-cluster)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[GpuCluster._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: GpuCluster._Status.ValueType  # 0
        CREATING: GpuCluster._Status.ValueType  # 1
        """GPU cluster is being created."""
        READY: GpuCluster._Status.ValueType  # 2
        """GPU cluster is ready to use."""
        ERROR: GpuCluster._Status.ValueType  # 3
        """GPU cluster encountered a problem and cannot operate."""
        DELETING: GpuCluster._Status.ValueType  # 4
        """GPU cluster is being deleted."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: GpuCluster.Status.ValueType  # 0
    CREATING: GpuCluster.Status.ValueType  # 1
    """GPU cluster is being created."""
    READY: GpuCluster.Status.ValueType  # 2
    """GPU cluster is ready to use."""
    ERROR: GpuCluster.Status.ValueType  # 3
    """GPU cluster encountered a problem and cannot operate."""
    DELETING: GpuCluster.Status.ValueType  # 4
    """GPU cluster is being deleted."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of GPU cluster."""
    folder_id: builtins.str
    """ID of the folder that the GPU cluster belongs to."""
    name: builtins.str
    """Name of the GPU cluster.

    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the GPU cluster."""
    status: global___GpuCluster.Status.ValueType
    """Status of the GPU cluster."""
    zone_id: builtins.str
    """ID of the availability zone where the GPU cluster resides."""
    interconnect_type: global___GpuInterconnectType.ValueType
    """Type of interconnect used for this GPU cluster."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """GPU cluster labels as `key:value` pairs."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___GpuCluster.Status.ValueType = ...,
        zone_id: builtins.str = ...,
        interconnect_type: global___GpuInterconnectType.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "interconnect_type", b"interconnect_type", "labels", b"labels", "name", b"name", "status", b"status", "zone_id", b"zone_id"]) -> None: ...

global___GpuCluster = GpuCluster



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.endpoint.api_endpoint_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetApiEndpointRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_ENDPOINT_ID_FIELD_NUMBER: builtins.int
    api_endpoint_id: builtins.str
    def __init__(
        self,
        *,
        api_endpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["api_endpoint_id", b"api_endpoint_id"]) -> None: ...

global___GetApiEndpointRequest = GetApiEndpointRequest

@typing.final
class ListApiEndpointsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListApiEndpointsRequest = ListApiEndpointsRequest

@typing.final
class ListApiEndpointsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def endpoints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.endpoint.api_endpoint_pb2.ApiEndpoint]: ...
    def __init__(
        self,
        *,
        endpoints: collections.abc.Iterable[yandex.cloud.endpoint.api_endpoint_pb2.ApiEndpoint] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["endpoints", b"endpoints", "next_page_token", b"next_page_token"]) -> None: ...

global___ListApiEndpointsResponse = ListApiEndpointsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v1/project_data_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5yandex/cloud/datasphere/v1/project_data_service.proto\x12\x1ayandex.cloud.datasphere.v1\x1a\x1dyandex/cloud/validation.proto\"S\n\x0c\x46ileMetadata\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x12\n\nsize_bytes\x18\x03 \x01(\x03\"m\n\x11UploadFileRequest\x12<\n\x08metadata\x18\x01 \x01(\x0b\x32(.yandex.cloud.datasphere.v1.FileMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\t\n\x07message\"P\n\x12UploadFileResponse\x12:\n\x08metadata\x18\x01 \x01(\x0b\x32(.yandex.cloud.datasphere.v1.FileMetadata\"Q\n\x13\x44ownloadFileRequest\x12!\n\nproject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=200\x12\x17\n\tfile_path\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"p\n\x14\x44ownloadFileResponse\x12<\n\x08metadata\x18\x01 \x01(\x0b\x32(.yandex.cloud.datasphere.v1.FileMetadataH\x00\x12\x0f\n\x05\x63hunk\x18\x02 \x01(\x0cH\x00\x42\t\n\x07message2\xf8\x01\n\x12ProjectDataService\x12m\n\nUploadFile\x12-.yandex.cloud.datasphere.v1.UploadFileRequest\x1a..yandex.cloud.datasphere.v1.UploadFileResponse(\x01\x12s\n\x0c\x44ownloadFile\x12/.yandex.cloud.datasphere.v1.DownloadFileRequest\x1a\x30.yandex.cloud.datasphere.v1.DownloadFileResponse0\x01\x42k\n\x1eyandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v1.project_data_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v1ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v1;datasphere'
  _FILEMETADATA.fields_by_name['project_id']._options = None
  _FILEMETADATA.fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _DOWNLOADFILEREQUEST.fields_by_name['project_id']._options = None
  _DOWNLOADFILEREQUEST.fields_by_name['project_id']._serialized_options = b'\350\3071\001\212\3101\005<=200'
  _DOWNLOADFILEREQUEST.fields_by_name['file_path']._options = None
  _DOWNLOADFILEREQUEST.fields_by_name['file_path']._serialized_options = b'\350\3071\001'
  _globals['_FILEMETADATA']._serialized_start=116
  _globals['_FILEMETADATA']._serialized_end=199
  _globals['_UPLOADFILEREQUEST']._serialized_start=201
  _globals['_UPLOADFILEREQUEST']._serialized_end=310
  _globals['_UPLOADFILERESPONSE']._serialized_start=312
  _globals['_UPLOADFILERESPONSE']._serialized_end=392
  _globals['_DOWNLOADFILEREQUEST']._serialized_start=394
  _globals['_DOWNLOADFILEREQUEST']._serialized_end=475
  _globals['_DOWNLOADFILERESPONSE']._serialized_start=477
  _globals['_DOWNLOADFILERESPONSE']._serialized_end=589
  _globals['_PROJECTDATASERVICE']._serialized_start=592
  _globals['_PROJECTDATASERVICE']._serialized_end=840
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Resource(google.protobuf.message.Message):
    """A Resource. For more information, see [Resource](/docs/iam/concepts/access-control/resources-with-access-control)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the resource."""
    type: builtins.str
    """The type of the resource, e.g. resource-manager.folder, billing.account, compute.snapshot, etc."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "type", b"type"]) -> None: ...

global___Resource = Resource



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/mdb/sqlserver/v1/config/sqlserver2019.proto\x12$yandex.cloud.mdb.sqlserver.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xf7\x02\n\x16SQLServerConfig2019std\x12H\n\x19max_degree_of_parallelism\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-99\x12P\n\x1e\x63ost_threshold_for_parallelism\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-32767\x12\x39\n\x0b\x61udit_level\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-3\x12\x43\n\x13\x66ill_factor_percent\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x41\n\x1doptimize_for_ad_hoc_workloads\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x9c\x02\n\x19SQLServerConfigSet2019std\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019std\"\xf7\x02\n\x16SQLServerConfig2019ent\x12H\n\x19max_degree_of_parallelism\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-99\x12P\n\x1e\x63ost_threshold_for_parallelism\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35-32767\x12\x39\n\x0b\x61udit_level\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03\x30-3\x12\x43\n\x13\x66ill_factor_percent\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-100\x12\x41\n\x1doptimize_for_ad_hoc_workloads\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\x9c\x02\n\x19SQLServerConfigSet2019ent\x12V\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent\x12Q\n\x0buser_config\x18\x02 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019ent\x12T\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32<.yandex.cloud.mdb.sqlserver.v1.config.SQLServerConfig2019entB~\n(yandex.cloud.api.mdb.sqlserver.v1.configZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1/config;sqlserverb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.sqlserver.v1.config.sqlserver2019_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.mdb.sqlserver.v1.configZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/sqlserver/v1/config;sqlserver'
  _SQLSERVERCONFIG2019STD.fields_by_name['max_degree_of_parallelism']._options = None
  _SQLSERVERCONFIG2019STD.fields_by_name['max_degree_of_parallelism']._serialized_options = b'\372\3071\0041-99'
  _SQLSERVERCONFIG2019STD.fields_by_name['cost_threshold_for_parallelism']._options = None
  _SQLSERVERCONFIG2019STD.fields_by_name['cost_threshold_for_parallelism']._serialized_options = b'\372\3071\0075-32767'
  _SQLSERVERCONFIG2019STD.fields_by_name['audit_level']._options = None
  _SQLSERVERCONFIG2019STD.fields_by_name['audit_level']._serialized_options = b'\372\3071\0030-3'
  _SQLSERVERCONFIG2019STD.fields_by_name['fill_factor_percent']._options = None
  _SQLSERVERCONFIG2019STD.fields_by_name['fill_factor_percent']._serialized_options = b'\372\3071\0050-100'
  _SQLSERVERCONFIG2019ENT.fields_by_name['max_degree_of_parallelism']._options = None
  _SQLSERVERCONFIG2019ENT.fields_by_name['max_degree_of_parallelism']._serialized_options = b'\372\3071\0041-99'
  _SQLSERVERCONFIG2019ENT.fields_by_name['cost_threshold_for_parallelism']._options = None
  _SQLSERVERCONFIG2019ENT.fields_by_name['cost_threshold_for_parallelism']._serialized_options = b'\372\3071\0075-32767'
  _SQLSERVERCONFIG2019ENT.fields_by_name['audit_level']._options = None
  _SQLSERVERCONFIG2019ENT.fields_by_name['audit_level']._serialized_options = b'\372\3071\0030-3'
  _SQLSERVERCONFIG2019ENT.fields_by_name['fill_factor_percent']._options = None
  _SQLSERVERCONFIG2019ENT.fields_by_name['fill_factor_percent']._serialized_options = b'\372\3071\0050-100'
  _globals['_SQLSERVERCONFIG2019STD']._serialized_start=162
  _globals['_SQLSERVERCONFIG2019STD']._serialized_end=537
  _globals['_SQLSERVERCONFIGSET2019STD']._serialized_start=540
  _globals['_SQLSERVERCONFIGSET2019STD']._serialized_end=824
  _globals['_SQLSERVERCONFIG2019ENT']._serialized_start=827
  _globals['_SQLSERVERCONFIG2019ENT']._serialized_end=1202
  _globals['_SQLSERVERCONFIGSET2019ENT']._serialized_start=1205
  _globals['_SQLSERVERCONFIGSET2019ENT']._serialized_end=1489
# @@protoc_insertion_point(module_scope)
